# -*- coding: utf-8 -*- 
# @Time    : 07/17/2024 
# @Author  : nzooherd 
# @File    : task.py 
# @Software: Visual Studio Code

import functools
from inspect import iscoroutinefunction
from logging import getLogger
import time


logger = getLogger()

def task_logger(func):

    @functools.wraps(func)
    async def async_wrapper(*args, **kwargs):
        # 打印任务开始时间和参数
        logger.info(f"Task {func.__name__} started. Arguments: {args}, {kwargs}")
        start_time = time.time()
        
        # 执行原始函数
        try:
            result = await func(*args, **kwargs)
            return result
        except Exception as e:
            logger.error("Task %s failed. %s", func.__name__, str(e))
        finally:
            # 打印任务结束时间和耗时
            end_time = time.time()
            logger.info(f"Task {func.__name__} ended. Execution time: {end_time - start_time:.2f} seconds")
        
    @functools.wraps(func)
    def sync_wrapper(*args, **kwargs):
        # 打印任务开始时间和参数
        logger.info(f"Task {func.__name__} started. Arguments: {args}, {kwargs}")
        start_time = time.time()
        
        # 执行原始函数
        try:
            result = func(*args, **kwargs)
            return result
        except Exception as e:
            logger.error("Task %s failed. %s", func.__name__, str(e))
        finally:
            # 打印任务结束时间和耗时
            end_time = time.time()
            logger.info(f"Task {func.__name__} ended. Execution time: {end_time - start_time:.2f} seconds")
    
        # 根据函数是否为协程函数选择包装器
    if iscoroutinefunction(func):
        return async_wrapper
    else:
        return sync_wrapper